==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-expansion-panel-component-event-args.js <==
import { ExpansionPanelComponentEventArgs as ExpansionPanelComponentEventArgs_internal } from "./ExpansionPanelComponentEventArgs";
var IgrExpansionPanelComponentEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrExpansionPanelComponentEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrExpansionPanelComponentEventArgs.prototype.createImplementation = function () {
        return new ExpansionPanelComponentEventArgs_internal();
    };
    Object.defineProperty(IgrExpansionPanelComponentEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrExpansionPanelComponentEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrExpansionPanelComponentEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrExpansionPanelComponentEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrExpansionPanelComponentEventArgs;
}());
export { IgrExpansionPanelComponentEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-expansion-panel-component-event-args.js <==
import { IgrExpansionPanel } from "./igr-expansion-panel";
import { ExpansionPanelComponentEventArgs as ExpansionPanelComponentEventArgs_internal } from "./ExpansionPanelComponentEventArgs";
var IgrExpansionPanelComponentEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrExpansionPanelComponentEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrExpansionPanelComponentEventArgs.prototype.createImplementation = function () {
        return new ExpansionPanelComponentEventArgs_internal();
    };
    Object.defineProperty(IgrExpansionPanelComponentEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrExpansionPanelComponentEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrExpansionPanelComponentEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrExpansionPanelComponentEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrExpansionPanel({});
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrExpansionPanelComponentEventArgs;
}());
export { IgrExpansionPanelComponentEventArgs };
